import { Platform } from 'react-native';
import { SlangFlightAssistantBridge } from './src/rn-bridge';

let __flightAssistantListener = {};

const checkOS = () => {
  if (Platform.OS === 'ios') {
    console.log("Slang doesn't support IOS yet!");
    return false;
  }
  return true;
};

const checkFunc = async (cb, func) => {
  if (!checkOS()) return false;

  if (typeof cb !== 'function') {
    throw 'Please provide a callback function for ' + func + ' !!';
  }

  return true;
};

const actionHandler = ({
  src_airport,
  dest_airport,
  status_date,
  flight_number,
}) => {
  const flightStatus = { status_date };
  if (src_airport !== 'UNKNOWN') {
    flightStatus['src_airport'] = src_airport;
  }
  if (dest_airport !== 'UNKNOWN') {
    flightStatus['dest_airport'] = dest_airport;
  }
  if (flight_number !== 999999) {
    flightStatus['flight_number'] = flight_number;
  }

  return __flightAssistantListener.onTrackStatus(flightStatus);
};

const errorHandler = (error) => {
  return __flightAssistantListener.onAssistantError(error);
};

const initialize = async (config) => {
  const check = checkOS();
  if (!check) return;

  let {
    buddyID,
    apiKey,
    locale = 'LOCALE_ENGLISH_IN',
    requestedLocales = ['LOCALE_ENGLISH_IN'],
    flightAssistantListener,
  } = config;

  SlangFlightAssistantBridge.initialize(buddyID, apiKey, {
    locale,
    requestedLocales,
  });

  checkFunc(flightAssistantListener.onTrackStatus, 'onTrackStatus');
  checkFunc(flightAssistantListener.onAssistantError, 'onAssistantError');
  __flightAssistantListener = flightAssistantListener;
  SlangFlightAssistantBridge.setActionHandler(actionHandler);
  SlangFlightAssistantBridge.setErrorHandler(errorHandler);
};

const show = () => {
  const check = checkOS();
  if (!check) return;

  SlangFlightAssistantBridge.show();
};

const hide = () => {
  const check = checkOS();
  if (!check) return;

  SlangFlightAssistantBridge.hide();
};

const setUserProperties = (userId, propertiesDictionary) => {
  const check = checkOS();
  if (!check) return;

  SlangFlightAssistantBridge.setUserProperties(userId, propertiesDictionary);
};

const notifyNonVoiceStatusQuery = ({
  src_airport,
  dest_airport,
  status_date,
  flight_number,
}) => {
  const check = checkOS();
  if (!check) return;

  const newStatusQuery = {
    src_airport,
    dest_airport,
    status_date,
    flight_number,
  };
  SlangFlightAssistantBridge.notifyNonVoiceStatusQuery(newStatusQuery);
};

export default {
  initialize,
  setUserProperties,
  notifyNonVoiceStatusQuery,
  show,
  hide,
};
