import { NativeModules, DeviceEventEmitter } from "react-native";

const { RNSlangFlightAssistant } = NativeModules;

class FlightAssistantBridge {
  //   Initializes Slang Flight Assistant
  initialize(buddyId, apiKey, config) {
    if (!config) config = {};
    config["buddyId"] = buddyId;
    config["apiKey"] = apiKey;
    RNSlangFlightAssistant.initialize(config);
    DeviceEventEmitter.addListener(
      "onTrackStatus",
      async (flightStatusQuery) => {
        try {
          const status = await this.flightActionHandler(flightStatusQuery);
          if (status === false) {
            RNSlangFlightAssistant.notifyActionCompleted(false);
          } else {
            RNSlangFlightAssistant.notifyActionCompleted(true);
          }
        } catch (e) {
          console.log("Error: Flight action handler", e);
          RNSlangFlightAssistant.notifyActionCompleted(false);
        }
      }
    );
    DeviceEventEmitter.addListener("onAssistantError", (params) => {
        this.flightErrorHandler(params);
    });
  }

  setActionHandler(actionHandler) {
    this.flightActionHandler = actionHandler;
  }

  setErrorHandler(errorHandler) {
    this.flightErrorHandler = errorHandler;
  }

  setUserProperties(userId, propertiesDictionary) {
    RNSlangFlightAssistant.setUserProperties(
      userId,
      propertiesDictionary
    );
  }

  notifyNonVoiceStatusQuery(statusQuery) {
    RNSlangFlightAssistant.notifyNonVoiceStatusQuery(statusQuery);
  }

  show() {
    RNSlangFlightAssistant.show();
  }

  hide() {
    RNSlangFlightAssistant.hide();
  }

  flightActionHandler = (flightQuery) => {};
  flightErrorHandler = (error) => {};

}

export const SlangFlightAssistantBridge = new FlightAssistantBridge();
